@@ -21,56 +21,85 @@ from sklearn.linear_model import LinearRegression
 from sklearn.linear_model import LogisticRegression
 from sklearn.model_selection import train_test_split
 
-class Lasso_RFE(LassoCV):
+class Lasso(Lasso):
+    """
+    Add feature importance to Lasso class similar to
+    random forest output.
+    """
+    def fit(self, *args, **kwargs):
+        super(Lasso, self).fit(*args, **kwargs)
+        self.feature_importances_ = np.abs(self.coef_).flatten()
+
+
+class LassoCV(LassoCV):
     """
     Add feature importance to Lasso class similar to
     random forest output. This has been updated to use
     CV for alpha tuning.
     """
     def fit(self, *args, **kwargs):
-        super(Lasso_RFE, self).fit(*args, **kwargs)
+        super(LassoCV, self).fit(*args, **kwargs)
         self.feature_importances_ = np.abs(self.coef_).flatten()
 
 
-class Ridge_RFE(RidgeCV):
+class Ridge(Ridge):
+    """
+    Add feature importance to Ridge class similar to
+    random forest output.
+    """
+    def fit(self, *args, **kwargs):
+        super(Ridge, self).fit(*args, **kwargs)
+        self.feature_importances_ = np.abs(self.coef_).flatten()
+
+
+class RidgeCV(RidgeCV):
     """
     Add feature importance to Ridge class similar to
     random forest output. This has been updated to use
     CV for alpha tuning.
     """
     def fit(self, *args, **kwargs):
-        super(Ridge_RFE, self).fit(*args, **kwargs)
+        super(RidgeCV, self).fit(*args, **kwargs)
         self.feature_importances_ = np.abs(self.coef_).flatten()
 
 
-class ElasticNet_RFE(ElasticNetCV):
+class ElasticNet(ElasticNet):
     """
     Add feature importance to ElasticNet class similar to
-    random forest output. Modified from Apua Paquola script.
-    This uses cross-validation to chose alpha.
+    random forest output.
     """
     def fit(self, *args, **kwargs):
-        super(ElasticNet_RFE, self).fit(*args, **kwargs)
+        super(ElasticNet, self).fit(*args, **kwargs)
         self.feature_importances_ = np.abs(self.coef_).flatten()
 
 
-class LogisticRegression_RFE(LogisticRegression):
+class ElasticNetCV(ElasticNetCV):
+    """
+    Add feature importance to ElasticNet class similar to
+    random forest output. This uses cross-validation to chose alpha.
+    """
+    def fit(self, *args, **kwargs):
+        super(ElasticNetCV, self).fit(*args, **kwargs)
+        self.feature_importances_ = np.abs(self.coef_).flatten()
+
+
+class LogisticRegression(LogisticRegression):
     """
     Add feature importance to Logistic Regression class similar to
     random forest output.
     """
     def fit(self, *args, **kwargs):
-        super(LogisticRegression_RFE, self).fit(*args, **kwargs)
+        super(LogisticRegression, self).fit(*args, **kwargs)
         self.feature_importances_ = np.abs(self.coef_).flatten()
 
 
-class LinearRegression_RFE(LinearRegression):
+class LinearRegression(LinearRegression):
     """
     Add feature importance to Linear Regression class similar to
     random forest output.
     """
     def fit(self, *args, **kwargs):
-        super(LinearRegression_RFE, self).fit(*args, **kwargs)
+        super(LinearRegression, self).fit(*args, **kwargs)
         self.feature_importances_ = np.abs(self.coef_).flatten()
 
 
@@ -78,7 +107,7 @@ def calculate_alpha(X, Y):
     """
     Using cross-validation with developmental set to learn
     alpha. This is for elastic net optimization. Note that
-    ElasticNet_RFE preforms this automatically.
+    ElasticNet preforms this automatically.
 
     Args:
     X: a data frame of normalized values from training dataset
