@@ -25,6 +25,7 @@ from .rank_function import features_rank_fnc
 from sklearn.metrics import mean_squared_error
 from sklearn.ensemble import RandomForestRegressor
 from sklearn.ensemble import RandomForestClassifier
+from sklearn.model_selection import train_test_split
 from sklearn.metrics import explained_variance_score
 from sklearn.inspection import permutation_importance
 from sklearn.metrics import normalized_mutual_info_score
@@ -166,15 +167,18 @@ def rf_fe_step(estimator, X, Y, n_features_to_keep, features, fold, out_dir,
     dict: a dictionary with number of features, normalized mutual
           information score, accuracy score, auc roc score and selected features
     """
-    assert n_features_to_keep <= X.shape[1]
-    estimator.fit(X, Y)
-    test_indices = np.array(range(X.shape[1]))
+    kwargs = {'random_state': 13, 'test_size': 0.20}
+    X1, X2, Y1, Y2 = train_test_split(X, Y, **kwargs)
+    assert n_features_to_keep <= X1.shape[1]
+    estimator.fit(X1, Y1)
+    test_indices = np.array(range(X1.shape[1]))
     res = permutation_importance(estimator, X2, Y2, n_jobs=-1, random_state=13)
     #rank = test_indices[np.argsort(estimator.feature_importances_)]
     rank = test_indices[res.importances_mean.argsort()]
     rank = rank[::-1] # reverse sort
     selected = rank[0:n_features_to_keep]
     features_rank_fnc(features, rank, n_features_to_keep, fold, out_dir, RANK)
+    estimator.fit(X, Y)
     if isinstance(estimator, RandomForestClassifier):
         return {'n_features': X.shape[1],
                 'nmi_score': oob_score_nmi(estimator, Y),
